export enum ProjectTypeEnum {
  FLINK = 1,
  SPARK = 2,
}

export enum CVSTypeEnum {
  GIT = 1,
  SVN = 2,
}
